@@ -9,7 +9,7 @@ import vtk
 sphere = vtk.vtkSphereSource()
 
 sphereMapper = vtk.vtkPolyDataMapper()
-sphereMapper.SetInput(sphere.GetOutput())
+sphereMapper.SetInputConnection(sphere.GetOutputPort())
 sphereMapper.GlobalImmediateModeRenderingOn()
 sphereActor = vtk.vtkLODActor()
 sphereActor.SetMapper(sphereMapper)
@@ -48,6 +48,7 @@ ren.AddActor(sphereActor)
 
 ren.SetBackground(1, 1, 1)
 renWin.SetSize(250, 125)
+ren.ResetCamera()
 ren.GetActiveCamera().Zoom(1.5)
 
 iren.Initialize()
