@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkmyEx1.cxx,v $
+  Module:    vtkmyEx1.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,7 +24,7 @@
 #include "vtkBar2.h"
 #include "vtkImageFoo.h"
 
-int main( int argc, char *argv[] )
+int main()
 {
 
   //
@@ -34,23 +34,23 @@ int main( int argc, char *argv[] )
 
   vtkBar *bar = vtkBar::New();
   bar->Print(cout);
-  
+
   //
   // Then we create an instance of vtkBar2
   //
   cout << "Create vtkBar2 object and print it." << endl;
-  
+
   vtkBar2 *bar2 = vtkBar2::New();
   bar2->Print(cout);
-  
+
   //
   // And we create an instance of vtkImageFoo
   //
   cout << "Create vtkImageFoo object and print it." << endl;
-  
+
   vtkImageFoo *imagefoo = vtkImageFoo::New();
   imagefoo->Print(cout);
-  
+
   cout << "Looks good ?" << endl;
 
   //
