@@ -1,35 +1,32 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkmyImagingWin32Header.h,v $
-  Language:  C++
-  Date:      $Date: 2002/03/13 23:54:45 $
-  Version:   $Revision: 1.3 $
+  Module:    vtkmyImagingWin32Header.h
 
-  Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
+  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
   See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
 // .NAME vtkmyImagingWin32Header - manage Windows system differences
 // .SECTION Description
 // The vtkmyImagingWin32Header captures some system differences between Unix
-// and Windows operating systems. 
+// and Windows operating systems.
 
-#ifndef __vtkmyImagingWin32Header_h
-#define __vtkmyImagingWin32Header_h
+#ifndef vtkmyImagingWin32Header_h
+#define vtkmyImagingWin32Header_h
 
 #include <vtkmyConfigure.h>
 
 #if defined(WIN32) && !defined(VTKMY_STATIC)
 #if defined(vtkmyImaging_EXPORTS)
-#define VTK_MY_IMAGING_EXPORT __declspec( dllexport ) 
+#define VTK_MY_IMAGING_EXPORT __declspec( dllexport )
 #else
-#define VTK_MY_IMAGING_EXPORT __declspec( dllimport ) 
+#define VTK_MY_IMAGING_EXPORT __declspec( dllimport )
 #endif
 #else
 #define VTK_MY_IMAGING_EXPORT
