@@ -1,17 +1,14 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkBar2.h,v $
-  Language:  C++
-  Date:      $Date: 2002/01/22 15:27:30 $
-  Version:   $Revision: 1.3 $
+  Module:    vtkBar2.h
 
-  Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
+  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
   See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
@@ -19,8 +16,8 @@
 // .SECTION Description
 // None.
 
-#ifndef __vtkBar2_h
-#define __vtkBar2_h
+#ifndef vtkBar2_h
+#define vtkBar2_h
 
 #include "vtkObject.h"
 #include "vtkmyUnsortedWin32Header.h"
@@ -29,14 +26,14 @@ class VTK_MY_UNSORTED_EXPORT vtkBar2 : public vtkObject
 {
 public:
   static vtkBar2 *New();
-  vtkTypeRevisionMacro(vtkBar2,vtkObject);
+  vtkTypeMacro(vtkBar2,vtkObject);
 
 protected:
-  vtkBar2() {};
-  ~vtkBar2() {};
+  vtkBar2() {}
+  ~vtkBar2() {}
 private:
   vtkBar2(const vtkBar2&);  // Not implemented.
   void operator=(const vtkBar2&);  // Not implemented.
 };
 
-#endif 
+#endif
