@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: pipe1.cxx,v $
+  Module:    pipe1.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -12,6 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
+
+#include "vtkCallbackCommand.h"
 #include "vtkImageData.h"
 #include "vtkOutputPort.h"
 #include "vtkRTAnalyticSource.h"
@@ -21,16 +23,19 @@
 static float XFreq = 60;
 
 // Increments XFreq of the synthetic source
-void IncrementXFreq(void* sr)
+static void IncrementXFreq(vtkObject *vtkNotUsed( caller ),
+                           unsigned long vtkNotUsed(eventId),
+                           void *sr, void *)
 {
   vtkRTAnalyticSource* source1 = reinterpret_cast<vtkRTAnalyticSource*>(sr);
   XFreq = XFreq + 10;
   source1->SetXFreq(XFreq);
 }
 
+
 // Pipe 1 for PipelineParallelism.
 // See PipelineParallelism.cxx for more information.
-void pipe1(vtkMultiProcessController* vtkNotUsed(controller), 
+void pipe1(vtkMultiProcessController* vtkNotUsed(controller),
            void* vtkNotUsed(arg))
 {
   double extent = 20;
@@ -38,7 +43,7 @@ void pipe1(vtkMultiProcessController* vtkNotUsed(controller),
 
   // Synthetic image source.
   vtkRTAnalyticSource* source1 = vtkRTAnalyticSource::New();
-  source1->SetWholeExtent (-1*iextent, iextent, -1*iextent, iextent, 
+  source1->SetWholeExtent (-1*iextent, iextent, -1*iextent, iextent,
                            -1*iextent, iextent );
   source1->SetCenter(0, 0, 0);
   source1->SetStandardDeviation( 0.5 );
@@ -53,15 +58,19 @@ void pipe1(vtkMultiProcessController* vtkNotUsed(controller),
 
   // Output port
   vtkOutputPort* op = vtkOutputPort::New();
-  op->SetInput(source1->GetOutput());
+  op->SetInputConnection(source1->GetOutputPort());
   op->SetTag(11);
-  // Turn this on for pipeline parallelism.
-  op->PipelineFlagOn();
+
   // Called every time data is requested from the output port
-  op->SetParameterMethod(IncrementXFreq, source1);
+  vtkCallbackCommand *cbc = vtkCallbackCommand::New();
+  cbc->SetCallback(IncrementXFreq);
+  cbc->SetClientData((void *)source1);
+  op->AddObserver(vtkCommand::EndEvent,cbc);
+  cbc->Delete();
+
   // Process requests
   op->WaitForUpdate();
-  
+
   // Cleanup
   op->Delete();
   source1->Delete();
