@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: AmbientSpheres.cxx,v $
+  Module:    AmbientSpheres.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -15,6 +15,7 @@
 //
 // This examples demonstrates the effect of specular lighting.
 //
+#include "vtkSmartPointer.h"
 #include "vtkSphereSource.h"
 #include "vtkPolyDataMapper.h"
 #include "vtkActor.h"
@@ -25,11 +26,11 @@
 #include "vtkCamera.h"
 #include "vtkLight.h"
 
-int main(int argc, char *argv[])
+int main()
 {
   // The following lines create a sphere represented by polygons.
   //
-  vtkSphereSource *sphere = vtkSphereSource::New();
+  vtkSmartPointer<vtkSphereSource> sphere = vtkSmartPointer<vtkSphereSource>::New();
   sphere->SetThetaResolution(100);
   sphere->SetPhiResolution(50);
 
@@ -37,8 +38,8 @@ int main(int argc, char *argv[])
   // library. It may also do color mapping, if scalars or other attributes
   // are defined.
   //
-  vtkPolyDataMapper *sphereMapper = vtkPolyDataMapper::New();
-  sphereMapper->SetInput(sphere->GetOutput());
+  vtkSmartPointer<vtkPolyDataMapper> sphereMapper = vtkSmartPointer<vtkPolyDataMapper>::New();
+  sphereMapper->SetInputConnection(sphere->GetOutputPort());
 
   // The actor is a grouping mechanism: besides the geometry (mapper), it
   // also has a property, transformation matrix, and/or texture map.
@@ -46,14 +47,14 @@ int main(int argc, char *argv[])
   // spheres) and set the specular lighting coefficients. A little ambient
   // is turned on so the sphere is not completely black on the back side.
   //
-  vtkActor *sphere1 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere1 = vtkSmartPointer<vtkActor>::New();
   sphere1->SetMapper(sphereMapper);
   sphere1->GetProperty()->SetColor(1,0,0);
   sphere1->GetProperty()->SetAmbient(0.125);
   sphere1->GetProperty()->SetDiffuse(0.0);
   sphere1->GetProperty()->SetSpecular(0.0);
 
-  vtkActor *sphere2 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere2 = vtkSmartPointer<vtkActor>::New();
   sphere2->SetMapper(sphereMapper);
   sphere2->GetProperty()->SetColor(1,0,0);
   sphere2->GetProperty()->SetAmbient(0.25);
@@ -61,7 +62,7 @@ int main(int argc, char *argv[])
   sphere2->GetProperty()->SetSpecular(0.0);
   sphere2->AddPosition(1.25,0,0);
 
-  vtkActor *sphere3 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere3 = vtkSmartPointer<vtkActor>::New();
   sphere3->SetMapper(sphereMapper);
   sphere3->GetProperty()->SetColor(1,0,0);
   sphere3->GetProperty()->SetAmbient(0.375);
@@ -69,7 +70,7 @@ int main(int argc, char *argv[])
   sphere3->GetProperty()->SetSpecular(0.0);
   sphere3->AddPosition(2.5,0,0);
 
-  vtkActor *sphere4 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere4 = vtkSmartPointer<vtkActor>::New();
   sphere4->SetMapper(sphereMapper);
   sphere4->GetProperty()->SetColor(1,0,0);
   sphere4->GetProperty()->SetAmbient(0.5);
@@ -77,7 +78,7 @@ int main(int argc, char *argv[])
   sphere4->GetProperty()->SetSpecular(0.0);
   sphere4->AddPosition(3.75,0,0);
 
-  vtkActor *sphere5 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere5 = vtkSmartPointer<vtkActor>::New();
   sphere5->SetMapper(sphereMapper);
   sphere5->GetProperty()->SetColor(1,0,0);
   sphere5->GetProperty()->SetAmbient(0.625);
@@ -85,7 +86,7 @@ int main(int argc, char *argv[])
   sphere5->GetProperty()->SetSpecular(0.0);
   sphere5->AddPosition(0.0,1.25,0);
 
-  vtkActor *sphere6 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere6 = vtkSmartPointer<vtkActor>::New();
   sphere6->SetMapper(sphereMapper);
   sphere6->GetProperty()->SetColor(1,0,0);
   sphere6->GetProperty()->SetAmbient(0.75);
@@ -93,7 +94,7 @@ int main(int argc, char *argv[])
   sphere6->GetProperty()->SetSpecular(0.0);
   sphere6->AddPosition(1.25,1.25,0);
 
-  vtkActor *sphere7 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere7 = vtkSmartPointer<vtkActor>::New();
   sphere7->SetMapper(sphereMapper);
   sphere7->GetProperty()->SetColor(1,0,0);
   sphere7->GetProperty()->SetAmbient(0.875);
@@ -101,7 +102,7 @@ int main(int argc, char *argv[])
   sphere7->GetProperty()->SetSpecular(0.0);
   sphere7->AddPosition(2.5,1.25,0);
 
-  vtkActor *sphere8 = vtkActor::New();
+  vtkSmartPointer<vtkActor> sphere8 = vtkSmartPointer<vtkActor>::New();
   sphere8->SetMapper(sphereMapper);
   sphere8->GetProperty()->SetColor(1,0,0);
   sphere8->GetProperty()->SetAmbient(1.0);
@@ -109,15 +110,15 @@ int main(int argc, char *argv[])
   sphere8->GetProperty()->SetSpecular(0.0);
   sphere8->AddPosition(3.75,1.25,0);
 
-  // Create the graphics structure. The renderer renders into the 
+  // Create the graphics structure. The renderer renders into the
   // render window. The render window interactor captures mouse events
   // and will perform appropriate camera or actor manipulation
   // depending on the nature of the events.
   //
-  vtkRenderer *ren1 = vtkRenderer::New();
-  vtkRenderWindow *renWin = vtkRenderWindow::New();
+  vtkSmartPointer<vtkRenderer> ren1 = vtkSmartPointer<vtkRenderer>::New();
+  vtkSmartPointer<vtkRenderWindow> renWin = vtkSmartPointer<vtkRenderWindow>::New();
   renWin->AddRenderer(ren1);
-  vtkRenderWindowInteractor *iren = vtkRenderWindowInteractor::New();
+  vtkSmartPointer<vtkRenderWindowInteractor> iren = vtkSmartPointer<vtkRenderWindowInteractor>::New();
   iren->SetRenderWindow(renWin);
 
   // Add the actors to the renderer, set the background and size.
@@ -135,7 +136,7 @@ int main(int argc, char *argv[])
 
   // Set up the lighting.
   //
-  vtkLight *light = vtkLight::New();
+  vtkSmartPointer<vtkLight> light = vtkSmartPointer<vtkLight>::New();
   light->SetFocalPoint(1.875,0.6125,0);
   light->SetPosition(0.875,1.6125,1);
   ren1->AddLight(light);
@@ -150,30 +151,13 @@ int main(int argc, char *argv[])
   ren1->GetActiveCamera()->ParallelProjectionOn();
   ren1->ResetCamera();
   ren1->GetActiveCamera()->SetParallelScale(1.5);
-  
+
   // This starts the event loop and invokes an initial render.
   //
   iren->Initialize();
   iren->Start();
 
-  // Exiting from here, we have to delete all the instances that
-  // have been created.
-  //
-  sphere->Delete();
-  sphereMapper->Delete();
-  sphere1->Delete();
-  sphere2->Delete();
-  sphere3->Delete();
-  sphere4->Delete();
-  sphere5->Delete();
-  sphere6->Delete();
-  sphere7->Delete();
-  sphere8->Delete();
-  ren1->Delete();
-  renWin->Delete();
-  iren->Delete();
-
-  return 0;
+  return EXIT_SUCCESS;
 }
 
 
